GatewayClient

Struct GatewayClient 

pub struct GatewayClient {
    http_address: String,
    iroh_node_id: NodeId,
    password: Option<String>,
    use_iroh: bool,
}

Fields

http_address: Stringiroh_node_id: NodeIdpassword: Option<String>use_iroh: bool

Implementations

Source

impl<'a> GatewayClient

pub fn new(gw: &'a Gatewayd) -> Self

pub fn cmd(&self) -> Command

pub fn with_password(self, password: &str) -> Self

pub fn with_iroh(self) -> Self

pub fn address(&self) -> String

pub async fn client_config(&self, fed_id: String) -> Result<GatewayFedConfig>

pub async fn gateway_id(&self) -> Result<String>

pub async fn get_info(&self) -> Result<Value>

pub async fn lightning_pubkey(&self) -> Result<PublicKey>

pub async fn connect_fed(&self, invite_code: String) -> Result<Value>

pub async fn recover_fed(&self, fed: &Federation) -> Result<()>

pub async fn backup_to_fed(&self, fed: &Federation) -> Result<()>

pub async fn get_pegin_addr(&self, fed_id: &str) -> Result<String>

pub async fn get_ln_onchain_address(&self) -> Result<String>

pub async fn get_mnemonic(&self) -> Result<MnemonicResponse>

pub async fn leave_federation( &self, federation_id: FederationId, ) -> Result<Value>

pub async fn create_invoice(&self, amount_msats: u64) -> Result<Bolt11Invoice>

pub async fn pay_invoice(&self, invoice: Bolt11Invoice) -> Result<()>

pub async fn send_ecash( &self, federation_id: String, amount_msats: u64, ) -> Result<String>

pub async fn receive_ecash(&self, ecash: String) -> Result<()>

pub async fn get_balances(&self) -> Result<GatewayBalances>

pub async fn ecash_balance(&self, federation_id: String) -> Result<u64>

pub async fn close_channel( &self, remote_pubkey: PublicKey, force: bool, ) -> Result<()>

pub async fn close_all_channels_no_wait(&self, force: bool) -> Result<()>

Send close requests for all channels without waiting for them to become inactive. See Self::close_all_channels for a version that polls until closure is confirmed.

pub async fn close_all_channels( &self, force: bool, timeout: Duration, ) -> Result<()>

Close all channels and poll until none are active.

Only waits for channels that existed at the time of the call, so channels opened while polling are ignored.

pub async fn open_channel( &self, gw: &Gatewayd, channel_size_sats: u64, push_amount_sats: Option<u64>, ) -> Result<Txid>

Open a channel with the gateway’s lightning node, returning the funding transaction txid.

pub async fn list_channels(&self) -> Result<Vec<ChannelInfo>>

pub async fn wait_for_block_height( &self, target_block_height: u64, ) -> Result<()>

pub async fn get_lightning_fee(&self, fed_id: String) -> Result<PaymentFee>

pub async fn set_federation_routing_fee( &self, fed_id: String, base: u64, ppm: u64, ) -> Result<()>

pub async fn set_federation_transaction_fee( &self, fed_id: String, base: u64, ppm: u64, ) -> Result<()>

pub async fn payment_summary(&self) -> Result<PaymentSummaryResponse>

pub async fn wait_bolt11_invoice(&self, payment_hash: Vec<u8>) -> Result<()>

pub async fn list_transactions( &self, start: SystemTime, end: SystemTime, ) -> Result<Vec<PaymentDetails>>

pub async fn create_offer(&self, amount: Option<Amount>) -> Result<String>

pub async fn pay_offer( &self, offer: String, amount: Option<Amount>, ) -> Result<()>

pub async fn send_onchain( &self, bitcoind: &Bitcoind, amount: BitcoinAmountOrAll, fee_rate: u64, ) -> Result<Txid>

pub async fn pegout( &self, fed_id: String, amount: u64, address: Address, ) -> Result<WithdrawResponse>